package WebGUI::i18n::Spanish::Asset_SyndicatedContent;
use utf8;
our $I18N = {
  1 => {
    'lastUpdated' => '1252455617',
    'message' => 'URL al Archivo RSS'
  },
  '1 description' => {
    'lastUpdated' => '1252455634',
    'message' => '<p>Indique el URL exacto (comenzando con http://) al archivo RDF o RSS del contenido a sindicar. El contenido a sindicar será descargado desde ese URL una vez cada hora.&nbsp;</p><p>Puede encontrar contenido a sindicar en:&nbsp;</p> <div> <ul>
<li><a href="http://www.newsisfree.com/">http://www.newsisfree.com</a></li>
<li><a href="http://www.syndic8.com/">http://www.syndic8.com</a></li>
<li><a href="http://www.voidstar.com/node.php?id=144">http://www.voidstar.com/node.php?id=144</a></li>
<li><a href="http://my.userland.com/">http://my.userland.com</a></li>
<li><a href="http://www.webreference.com/services/news/">http://www.webreference.com/services/news/</a></li>
<li><a href="http://w.moreover.com/">http://w.moreover.com/</a></li>
</ul>
 </div> <p>WebGUI puede manejar RSS versiones .90, .91, 1.0 y 2.0. No soporta fuentes Atom por ahora. Es probable que otros archivos con un formato similar a RSS funcionen.</p><p>Para crear un RSS agregado (uno que obtiene titulares desde varias fuentes RSS), incluya la lista de URLs, uno por línea. Los titulares serán ordenados según la fecha en la que WebGUI recibió la historia por primera vez.</p>'
  },
  3 => {
    'lastUpdated' => '1252455668',
    'message' => 'Número Máximo de Titulares'
  },
  '3 description' => {
    'lastUpdated' => '1224522341',
    'message' => 'Introduzca la cantidad m&aacute;xima de titulares que deben ser presentados. Indique cero para permitir una cantidad ilimitada de titulares. Note que todos los titulares son consultados a&uacute;n cuando s&oacute;lo se presenten un subconjunto de ellos.'
  },
  4 => {
    'lastUpdated' => '1224522378',
    'message' => 'Editar Contenido Sindicado'
  },
  72 => {
    'lastUpdated' => '1224522390',
    'message' => 'Plantilla para Contenido Sindicado'
  },
  '72 description' => {
    'lastUpdated' => '1224522412',
    'message' => 'Seleccione la Plantilla con la cual presentar el Contenido Sindicado.'
  },
  'RSS Feed Title Suffix' => {
    'lastUpdated' => '1224522426',
    'message' => 'Fuente RSS 2.0'
  },
  'assetName' => {
    'lastUpdated' => '1224522434',
    'message' => 'Contenido Sindicado'
  },
  'atom_url' => {
    'lastUpdated' => '1227147421',
    'message' => 'Los contenidos de este Activo presentados como una fuente Atom 0.3'
  },
  'author' => {
    'lastUpdated' => '1227147461',
    'message' => 'El publicador de este item.'
  },
  'cache timeout' => {
    'lastUpdated' => '1224524488',
    'message' => 'Tiempo a mantener en cach&eacute;'
  },
  'cache timeout help' => {
    'lastUpdated' => '1224525840',
    'message' => 'Como todos los usuarios ver&aacute;n siempre el mismo recurso, es conveniente mantenerlo en cache para mejorar el desempe&ntilde;o. &iquest;Por cu&aacute;nto tiempo debemos mantenerlo en el cache?'
  },
  'cacheTimeout' => {
    'lastUpdated' => '1224525880',
    'message' => 'Tiempo en segundos a mantener el recurso en cache.'
  },
  'category' => {
    'lastUpdated' => '1227147485',
    'message' => 'La categor&iacute;a a la cual pertenece este item.'
  },
  'channel.description' => {
    'lastUpdated' => '1224525982',
    'message' => 'La descripci&oacute;n del contenido disponible a trav&eacute;s de este canal. Ser&aacute; la misma descripci&oacute;n utilizada al crear el Activo agregador de Contenido Sindicado.'
  },
  'channel.link' => {
    'lastUpdated' => '1224526032',
    'message' => 'URL al sitio origen del canal. Esta variable no existe cuando se crea un agregador, porque no existe un URL &uacute;nico al cual enlazar.'
  },
  'channel.title' => {
    'lastUpdated' => '1224526237',
    'message' => 'El t&iacute;tulo de este Contenido Sindicado. Ser&aacute; el mismo t&iacute;tulo utilizado para el Contenido Sindicado en modo agregador.'
  },
  'channel_copyright' => {
    'lastUpdated' => '1227147569',
    'message' => 'Informaci&oacute;n del propietario del Copyright. El valor de esta variable ser&aacute; establecido con la primera fuente de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_date' => {
    'lastUpdated' => '1227147676',
    'message' => 'La fecha en la que este canal fue actualizado por &uacute;ltima vez. El valor de esta variable ser&aacute; establecido por la primera fuente en las lista de m&uacute;ltiples fuentes.'
  },
  'channel_description' => {
    'lastUpdated' => '1227147809',
    'message' => 'La descripci&oacute;n del contenido disponible a trav&eacute;s de este canal. El valor de esta variable lo establece la primera fuente de la lista de m&uacute;ltiples fuentes.'
  },
  'channel_image_description' => {
    'lastUpdated' => '1227147858',
    'message' => 'La descripci&oacute;n de la imagen asociada con esta fuente. El valor de esta variable lo establece la primera fuente para el caso de listas de m&uacute;ltiples fuentes.'
  },
  'channel_image_height' => {
    'lastUpdated' => '1227149628',
    'message' => 'La altura en pixels de la imagen asociada a esta fuente. El valor de esta variable es establecido por la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_image_link' => {
    'lastUpdated' => '1227148679',
    'message' => 'El URL del enlace que envuelve a la imagen asociada a esta fuente. El valor de esta variable ser&aacute; establecido por la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_image_title' => {
    'lastUpdated' => '1227149288',
    'message' => 'El t&iacute;tulo de la imagen asociada a esta fuente. El valor de esta variable lo establece la primera fuente cuando se trata de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_image_url' => {
    'lastUpdated' => '1227149586',
    'message' => 'El URL de la imagen asociada a esta fuente. El valor de esta variable lo establece la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_image_width' => {
    'lastUpdated' => '1227149643',
    'message' => 'La anchura en pixels de la imagen asociada a esta fuente. El valor de esta variable es establecido por la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_link' => {
    'lastUpdated' => '1227149942',
    'message' => 'El URL al sitio origen de la fuente. El valor de esta variable lo establece la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'channel_title' => {
    'lastUpdated' => '1227150065',
    'message' => 'El t&iacute;tulo del fragmento de contenido sindicado. El valor de esta variable lo establece la primera fuente en el caso de una lista de m&uacute;ltiples fuentes.'
  },
  'date' => {
    'lastUpdated' => '1234631545',
    'message' => 'La fecha de publicación de este ítem.'
  },
  'description' => {
    'lastUpdated' => '1224526286',
    'message' => 'La descripci&oacute;n del contenido. Si est&aacute; aplicando filtros basados en contenido, este atributo tambi&eacute;n ser&aacute; examinado.'
  },
  'descriptionFirst100words' => {
    'lastUpdated' => '1276808899',
    'message' => 'Las primeras cien (100) palabras de la descripción, sin HTML.'
  },
  'descriptionFirst10words' => {
    'lastUpdated' => '1276808910',
    'message' => 'Las primeras diez (10) palabras de la descripción, sin HTML.'
  },
  'descriptionFirst25words' => {
    'lastUpdated' => '1276810694',
    'message' => 'Las primeras veinticinco (25) palabras de la descripción, sin HTML.'
  },
  'descriptionFirst2paragraphs' => {
    'lastUpdated' => '1276810713',
    'message' => 'Los primeros dos (2) párrafos de la descripción, sin HTML.'
  },
  'descriptionFirst2sentences' => {
    'lastUpdated' => '1276810730',
    'message' => 'Las primeras dos (2) frases de la descripción, sin HTML.'
  },
  'descriptionFirst3sentences' => {
    'lastUpdated' => '1276810740',
    'message' => 'Las primeras tres (3) frases de la descripción, sin HTML.'
  },
  'descriptionFirst4sentences' => {
    'lastUpdated' => '1276810749',
    'message' => 'Las primeras cuatro (4) frases de la descripción, sin HTML.'
  },
  'descriptionFirst50words' => {
    'lastUpdated' => '1276810758',
    'message' => 'Las primeras cincuenta (50) palabras de la descripción, sin HTML.'
  },
  'descriptionFirst75words' => {
    'lastUpdated' => '1276810768',
    'message' => 'Las primeras setenta y cinco (75) palabras de la descripción, sin HTML.'
  },
  'descriptionFirstParagraph' => {
    'lastUpdated' => '1276810781',
    'message' => 'El primer párrafo de la descripción, sin HTML.'
  },
  'descriptionFirstSentence' => {
    'lastUpdated' => '1276810792',
    'message' => 'La primera frase de la descripción, sin HTML.'
  },
  'displayMode' => {
    'lastUpdated' => '1224526613',
    'message' => 'Si el Activo fue configurado para ordenar los titulares RSS seg&uacute;n el t&iacute;tulo del origen RSS, esta variable tendr&aacute; el valor &quot;grouped&quot;. En caso contrario, tendr&aacute; el valor &quot;interleaved&quot;.'
  },
  'displayModeLabel' => {
    'lastUpdated' => '1224526624',
    'message' => 'Modo de Presentaci&oacute;n'
  },
  'displayModeLabel description' => {
    'lastUpdated' => '1224527066',
    'message' => 'Si est&aacute; agregando fuentes RSS, puede cambiar el modo en el cual los items son presentados. &quot;Agrupado por Fuente&quot; indica que los items ser&aacute;n agrupados seg&uacute;n la fuente de la cual fueron obtenidos. &quot;Mezclados&quot; indica que los items ser&aacute;n mezclados tom&aacute;ndolos uno a uno de los diversos or&iacute;genes. Si est&aacute; agrupando las fuentes, por favor mire la variable de plantilla new_rss_site, que le permite acceder al t&iacute;tulo de la fuente para cada item.'
  },
  'displayModeSubtext' => {
    'lastUpdated' => '1224527165',
    'message' => '&quot;Mezclados&quot; indica que los items de todas las fuentes son combinados en un s&oacute;lo grupo, mientras que &quot;Agrupados por Fuente&quot; indica que se separan seg&uacute;n la fuente de la cual fueron recuperados. Da lo mismo cualquiera de los modos si solamente se est&aacute; utilizando una fuente.'
  },
  'feed order' => {
    'lastUpdated' => '1276810824',
    'message' => 'Orden de la Fuente'
  },
  'get syndicated content' => {
    'lastUpdated' => '1224527183',
    'message' => 'Obtener Contenido Sindicado'
  },
  'grouped' => {
    'lastUpdated' => '1224527385',
    'message' => 'Agrupados por Fuente'
  },
  'guid' => {
    'lastUpdated' => '1227150261',
    'message' => 'El identificador &uacute;nico para este item.'
  },
  'hasTerms' => {
    'lastUpdated' => '1224527230',
    'message' => 'T&eacute;rminos para filtrar items RSS.'
  },
  'hasTermsLabel' => {
    'lastUpdated' => '1224527245',
    'message' => 'Con cualquiera de estos t&eacute;rminos.'
  },
  'hasTermsLabel description' => {
    'lastUpdated' => '1224527347',
    'message' => '<p>Escriba t&eacute;rminos separados por comas que quiere utilizar para filtrar las fuentes. Por ejemplo, si escribe:</p> <div class="helpIndent"><strong>linux, windows development, blogs</strong></div> <p>El Activo de Contenido Sindicado mostrar&aacute; aquellos items de cualquiera de las fuentes agregadas que contengan &quot;linux&quot;, &quot;windows development&quot; o &quot;blogs&quot; en el t&iacute;tulo o en la descripci&oacute;n del item.</p>'
  },
  'interleaved' => {
    'lastUpdated' => '1224527392',
    'message' => 'Mezclados'
  },
  'item_loop' => {
    'lastUpdated' => '1224527413',
    'message' => 'Un ciclo para iterar sobre los datos para este canal RSS.'
  },
  'link' => {
    'lastUpdated' => '1224527433',
    'message' => 'URL al contenido del item.'
  },
  'maxHeadlines' => {
    'lastUpdated' => '1224527449',
    'message' => 'N&uacute;mero m&aacute;ximo de titulares a mostrar.'
  },
  'media' => {
    'lastUpdated' => '1302873353',
    'message' => 'Cualquier entrada MediaRSS para este item. Su estructura es copiada directamente usando el módulo XML::FeedPP::MediaRSS'
  },
  'new_rss_site' => {
    'lastUpdated' => '1224527543',
    'message' => 'Un condicional que indica haber iniciado la presentaci&oacute;n de los items de una fuente RSS diferente la del item previo. Esto tiene utilidad cuando las fuentes est&aacute;n siendo presentadas en modo &quot;Agrupados por Fuente&quot;, pues permite acceder a las variables <strong>site_title</strong> y <strong>site_link</strong> en el momento preciso.'
  },
  'no order' => {
    'lastUpdated' => '1276811800',
    'message' => 'Desordenados'
  },
  'process macros in rss url' => {
    'lastUpdated' => '1224527644',
    'message' => 'Procesar Macros en el URL de la fuente RSS.'
  },
  'process macros in rss url description' => {
    'lastUpdated' => '1224527578',
    'message' => 'Indicar &quot;Si&quot; permite el uso de macros en los URLs.'
  },
  'processMacrosInRssUrl' => {
    'lastUpdated' => '1224527628',
    'message' => 'Un condicional que indica si el Activo debe procesar Macros WebGUI dentro del URL de la fuente RSS.'
  },
  'publication date ascending' => {
    'lastUpdated' => '1276811881',
    'message' => 'Fecha de Publicación (viejos primero)'
  },
  'publication date descending' => {
    'lastUpdated' => '1276811907',
    'message' => 'Fecha de Publicación (nuevos primero)'
  },
  'rdf_url' => {
    'lastUpdated' => '1227150475',
    'message' => 'Los contenidos de este Activo en formato RDF/RSS 1.0'
  },
  'rss.url' => {
    'lastUpdated' => '1224527738',
    'message' => 'Este es el URL que se utiliza para obtener el Contenido Sindicado como una fuente RSS 2.0. Puede indicar versiones RSS diferentes mediante las variables para plantilla siguientes:'
  },
  'rss.url.0.9' => {
    'lastUpdated' => '1224527784',
    'message' => 'Este Activo de Contenido Sindicado es una fuente RSS 0.9.'
  },
  'rss.url.0.91' => {
    'lastUpdated' => '1224527795',
    'message' => 'Este Activo de Contenido Sindicado es una fuente RSS 0.91.'
  },
  'rss.url.1.0' => {
    'lastUpdated' => '1224527805',
    'message' => 'Este Activo de Contenido Sindicado es una fuente RSS 1.0.'
  },
  'rss.url.2.0' => {
    'lastUpdated' => '1224527815',
    'message' => 'Este Activo de Contenido Sindicado es una fuente RSS 2.0.'
  },
  'rssTabName' => {
    'lastUpdated' => '1224527822',
    'message' => 'RSS'
  },
  'rssUrl' => {
    'lastUpdated' => '1224527854',
    'message' => 'Lista de URLs a fuentes RSS, uno por l&iacute;nea.'
  },
  'rss_url' => {
    'lastUpdated' => '1227150549',
    'message' => 'URL para obtener los contenidos de este Activo en formato RSS 2.0. Adicionalmente es posible especificar una versi&oacute;n RSS diferente aprovechando las siguientes Variables para Plantilla:'
  },
  'site_link' => {
    'lastUpdated' => '1224527871',
    'message' => 'Enlace a la fuente RSS.'
  },
  'site_title' => {
    'lastUpdated' => '1224527888',
    'message' => 'T&iacute;tulo de la fuente RSS de la cual proviene este item.'
  },
  'sortItemsLabel' => {
    'lastUpdated' => '1272376152',
    'message' => '¿Ordenar los items por fecha?'
  },
  'sortItemsLabel description' => {
    'lastUpdated' => '1272376180',
    'message' => 'Si se activa, los items apareceran ordenados por fecha; si se desactiva, los items aparecerán en el mismo orden que en la fuente.'
  },
  'syndicated content asset template variables title' => {
    'lastUpdated' => '1224527908',
    'message' => 'Variables para Plantilla del Activo de Contenido Sindicado'
  },
  'templateId' => {
    'lastUpdated' => '1224527924',
    'message' => 'ID de la plantilla utilizada para presentar el Contenido Sindicado.'
  },
  'title' => {
    'lastUpdated' => '1224528002',
    'message' => 'T&iacute;tulo del item a presentar. Si est&aacute; aplicando filtros para seleccionar los items de inter&eacute;s, este campo ser&aacute; examinado.<br /> '
  }
}
;

1;
